Description
============

A simple library for functional reactive programming in Python, very loosely
based on the `wires <https://hackage.haskell.org/package/wires>`_ Haskell package.

Introduction
------------

Example
-------
